==> PatryksAutoAI-0.3.5-py3-none-any.whl: KaggleAutoAI/automated_ai/classification/compexity_level0.py <==
from ...regression.models.cat import Cat
from ...model_data.model_data import ModelData
from sklearn.model_selection import train_test_split, KFold
import logging
logging.basicConfig(level=logging.WARNING)

def Complexity_Level0(model, X, y):
    if model == "Cat":
        model = Cat()
    ## other model

    print(f"Chosen model {model} starting choosing important columns \n\n")
    importance_columns = {}
    for col in X.columns:
        importance_columns[col] = 0

    ## fix null columns
    model_data = ModelData(X)
    columns_null = model_data.find_null_column()
    for col in columns_null:
        column_data_type = X[col].dtype
        if column_data_type == "object":
            model_data.fix_column_str(col)
        else:
            model_data.fix_columns([col], "mean")
    
    ## Text column to dummies
    for col in X.columns:
        if X[col].dtype == "object" and X[col].nunique() < 10:
            model_data.dummies(col)
    X = model_data.return_dataframe()

    ## Train model in diffrent samples to extract importance of columns
    kfold = KFold(n_splits=5, shuffle=True, random_state=42)
    for i, (train_index, valid_index) in enumerate(kfold.split(X,y)):
        X_train, y_train = X.iloc[train_index], y.iloc[train_index]
        model.create_optuna(X_train,y_train,n_trials=100)
        feature_model = model.get()
        features = feature_model.get_feature_importance()
        for i,col in enumerate(X.columns):
            importance_columns[col] += features[i]

    print(f"Importance of columns: \n")
    for k,v in importance_columns.items():
        print(f"{k}: {v} \n")
    
    ## Acceptting column that satify the requirenments 
    mean_importance = sum(importance_columns.values()) / len(importance_columns)
    threshold_importance = 0.75 * mean_importance
    columns = []
    for k,v in importance_columns.items():
        if v > threshold_importance:
            columns.append(k)
            
    print(f"Used columns: {columns}")
    X = X[[columns]]
    model.create_optuna(X,y,n_trials=500)
    return model.get(), columns

==> PatryksAutoAI-0.3.7-py3-none-any.whl: KaggleAutoAI/automated_ai/classification/compexity_level0.py <==
from ...regression.models.cat import Cat
from ...model_data.model_data import ModelData
from sklearn.model_selection import train_test_split, KFold


def Complexity_Level0(model_name, X, y):
    if model_name == "Cat":
        model = Cat()
    ## other model

    print(f"Chosen model {model_name} starting choosing important columns \n\n")
    importance_columns = {}
    for col in X.columns:
        importance_columns[col] = 0

    ## fix null columns
    model_data = ModelData(X)
    columns_null = model_data.find_null_column()
    for col in columns_null:
        column_data_type = X[col].dtype
        if column_data_type == "object":
            model_data.fix_column_str(col)
        else:
            model_data.fix_columns([col], "mean")
    
    ## Text column to dummies
    for col in X.columns:
        if X[col].dtype == "object" and X[col].nunique() < 10:
            model_data.dummies(col)
    X = model_data.return_dataframe()

    ## Train model in diffrent samples to extract importance of columns
    kfold = KFold(n_splits=5, shuffle=True, random_state=42)
    for i, (train_index, valid_index) in enumerate(kfold.split(X,y)):
        X_train, y_train = X.iloc[train_index], y.iloc[train_index]
        model.create_optuna(X_train,y_train,n_trials=100)
        feature_model = model.get()
        features = feature_model.get_feature_importance()
        for i,col in enumerate(X.columns):
            importance_columns[col] += features[i]
    
    ## Acceptting column that satify the requirenments 
    mean_importance = sum(importance_columns.values()) / len(importance_columns)
    threshold_importance = 0.75 * mean_importance
    columns = []
    for k,v in importance_columns.items():
        if v > threshold_importance:
            columns.append(k)

    X = X[columns]
    model.create_optuna(X,y,n_trials=500)
    return model.get(), columns
